@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -47,14 +47,16 @@ $fields = [
 	'graphtype' =>		[T_ZBX_INT,			O_OPT, null,		IN('0,1'),			null],
 	'yaxismin' =>		[T_ZBX_DBL,			O_OPT, null,		null,				null],
 	'yaxismax' =>		[T_ZBX_DBL,			O_OPT, null,		null,				null],
-	'percent_left' =>	[T_ZBX_DBL,			O_OPT, null,		BETWEEN(0, 100),	null],
-	'percent_right' =>	[T_ZBX_DBL,			O_OPT, null,		BETWEEN(0, 100),	null],
+	'percent_left' =>	[T_ZBX_DBL,			O_OPT, null,		BETWEEN_DBL(0, 100, 4),	null],
+	'percent_right' =>	[T_ZBX_DBL,			O_OPT, null,		BETWEEN_DBL(0, 100, 4),	null],
 	'outer' =>			[T_ZBX_INT,			O_OPT, null,		IN('0,1'),			null],
 	'items' =>			[T_ZBX_STR,			O_OPT, null,		null,				null],
+	'i' =>				[T_ZBX_STR,			O_OPT, null,		null,				null],
 	'onlyHeight' =>		[T_ZBX_INT,			O_OPT, null,		IN('0,1'),			null],
 	'widget_view' =>	[T_ZBX_INT,			O_OPT, null,		IN('0,1'),			null]
 ];
 if (!check_fields($fields)) {
+	session_write_close();
 	exit();
 }
 validateTimeSelectorPeriod(getRequest('from'), getRequest('to'));
@@ -99,7 +101,14 @@ if ($httptestid = getRequest('httptestid', false)) {
 
 	$name = getRequest('name', '');
 }
-elseif ($items = getRequest('items', [])) {
+elseif (hasRequest('i') || hasRequest('items')) {
+	if (hasRequest('i')) {
+		$items = array_map('expandShortGraphItem', getRequest('i', []));
+	}
+	else {
+		$items = getRequest('items', []);
+	}
+
 	CArrayHelper::sort($items, ['sortorder']);
 
 	$dbItems = API::Item()->get([
@@ -120,17 +129,23 @@ elseif ($items = getRequest('items', [])) {
 			access_deny();
 		}
 		$host = reset($dbItems[$item['itemid']]['hosts']);
-		unset($dbItems[$item['itemid']]['hosts']);
 		$graph_items[] = $dbItems[$item['itemid']] + $item + [
 			'host' => $host['host'],
 			'hostname' => $host['name']
 		];
 	}
+
+	foreach ($graph_items as &$graph_item) {
+		unset($graph_item['hosts']);
+	}
+	unset($graph_item);
+
 	$name = getRequest('name', '');
 }
 else {
 	show_error_message(_('No items defined.'));
-	exit;
+	session_write_close();
+	exit();
 }
 
 /*
@@ -175,15 +190,10 @@ foreach ($graph_items as $graph_item) {
 
 if (getRequest('onlyHeight', '0') === '1') {
 	$graph->drawDimensions();
-	$height = $graph->getHeight() + 1;
-
-	if (getRequest('widget_view') === '1') {
-		$height = $height - CLineGraphDraw::DEFAULT_TOP_BOTTOM_PADDING;
-	}
-	header('X-ZBX-SBOX-HEIGHT: '.$height);
+	header('X-ZBX-SBOX-HEIGHT: '.($graph->getHeight() + 1));
 }
 else {
 	$graph->draw();
 }
 
-require_once dirname(__FILE__).'/include/page_footer.php';
+require_once __DIR__.'/include/page_footer.php';
