@@ -91,7 +91,7 @@ else {
 				(new CFormList())
 					->addRow(
 						new CLabel($data['context'] === 'host' ? _('Host groups') : _('Template groups'),
-							'filter_groups__ms'
+							'filter_groupids__ms'
 						),
 						(new CMultiSelect([
 							'name' => 'filter_groupids[]',
@@ -110,7 +110,7 @@ else {
 						]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 					)
 					->addRow(
-						new CLabel($data['context'] === 'host' ? _('Hosts') : _('Templates'), 'filter_hosts__ms'),
+						(new CLabel(($data['context'] === 'host') ? _('Hosts') : _('Templates'), 'filter_hostids__ms')),
 						(new CMultiSelect([
 							'name' => 'filter_hostids[]',
 							'object_name' => $data['context'] === 'host' ? 'hosts' : 'templates',
